"""Stop the daemon."""

import typer

from mb_stash.cli.context import use_context


def stop(ctx: typer.Context) -> None:
    """Stop the daemon."""
    app = use_context(ctx)
    app.core.service.stop()
    app.out.print_stopped()
