"""Hidden CLI command: run the daemon process."""

import typer

from mb_stash.cli.context import use_context


def daemon(ctx: typer.Context) -> None:
    """Run the daemon process. Not intended for manual use."""
    app = use_context(ctx)
    app.core.run_daemon()
