"""Show daemon status."""

import typer

from mb_stash.cli.context import use_context


def health(ctx: typer.Context) -> None:
    """Show daemon status (running, locked/unlocked)."""
    app = use_context(ctx)
    status = app.core.service.health()
    app.out.print_health(running=status.running, locked=status.locked)
