"""Lock the stash and clear clipboard."""

import typer

from mb_stash.cli.context import use_context


def lock(ctx: typer.Context) -> None:
    """Lock the stash and clear clipboard."""
    app = use_context(ctx)
    app.core.service.lock()
    app.out.print_locked()
